import { useMachine } from '@xstate/react';
import { LoggerController } from '../controllers/LoggerController';
export const useRookLogger = () => {
  const [_, send] = useMachine(LoggerController);
  const initLogger = props => {
    const {
      clientUUID,
      environment,
      sdkInfo,
      userID
    } = props;
    send({
      type: 'init',
      payload: {
        clientUUID,
        environment,
        sdkInfo,
        userID
      }
    });
  };
  const sendExtractionLog = content => {
    send({
      type: 'send',
      payload: content
    });
  };
  const sendTransmissionLog = content => {
    send({
      type: 'send',
      payload: content
    });
  };

  /**
   * The `logBoundary` function is a TypeScript function that wraps another function and logs the
   * success or failure of the wrapped function.
   * @param props - The `props` parameter is an object that contains the following properties:
   * @returns The function `logBoundary` returns a `Promise` that resolves to the response from the
   * `fun` function.
   */
  const logBoundary = async props => {
    const {
      fun,
      logSuccess,
      payload,
      logType,
      dataType
    } = props;
    try {
      const response = await fun(payload);
      if (logSuccess) sendLog({
        dataType,
        logType,
        message: {
          status: 'Success',
          description: logType.event === 'extract' ? '' : 'created'
        }
      });
      return response;
    } catch (error) {
      const copy = logType;
      if (error.message && error.message.includes('YYYY-MM-DD')) {
        copy.date = new Date().toISOString();
      }
      sendLog({
        dataType,
        logType: copy,
        message: {
          status: 'Failure',
          description: `${error}`
        }
      });
      throw error;
    }
  };

  /**
   * The function `sendLog` sends log messages based on the log type, either extraction or
   * transmission.
   * @param {LogSelector}  - - `dataType`: The type of data being logged.
   */
  const sendLog = _ref => {
    let {
      dataType,
      message,
      logType
    } = _ref;
    if (logType.type === 'extraction') sendExtractionLog({
      data_type: dataType,
      data_datetime: logType.date,
      status: message.status,
      failure_reason: message.description ? message.description : undefined,
      event: logType.event
    });else sendTransmissionLog({
      data_type: dataType,
      data_datetime: logType.date,
      server_response: message.description,
      event: logType.event
    });
  };
  return {
    initLogger,
    sendExtractionLog,
    sendTransmissionLog,
    logBoundary
  };
};
//# sourceMappingURL=useRookLogger.js.map