export type DeviceInfo = {
  brand: string;
  model: string;
  os_version?: string;
};

export type SDKInfo = {
  version: string;
  framework: 'ReactNative';
};

export type Status = 'Success' | 'Failure';

export type Event = 'extract' | 'send' | 'clear' | 'enqueue';

export type ExtractionLog = {
  data_type: string;
  data_datetime: string;
  status: Status;
  event: Event;
  failure_reason?: string;
};

export type TransmissionLog = {
  data_type: string;
  data_datetime: string;
  server_response: string;
  event: Event;
  response_time?: string;
};

export type LoggerContext = {
  clientUUID: string;
  content: ExtractionLog | TransmissionLog | null;
  deviceInfo: DeviceInfo | null;
  environment: 'development' | 'production' | 'sandbox';
  sdkInfo: SDKInfo | null;
  timestamp: string;
  userID: string;
};

export type LoggerEvent =
  | { type: 'send'; payload: ExtractionLog | TransmissionLog }
  | {
      type: 'init';
      payload: Partial<LoggerContext> &
        Omit<LoggerContext, 'timestamp' | 'content' | 'deviceInfo' | 'userID'>;
    };
